==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/GISLAYERCRITERIA_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for GISLAYERCRITERIA_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GISLAYERCRITERIA_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISLAYER"/>
 *         &lt;element name="GISFILTER" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="GISRADIUS" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="DISTANCE" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *                   &lt;element name="UOM" type="{http://schemas.datastream.net/MP_fields}TYPE_Type"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GISLAYERCRITERIA_Type", propOrder = {
    "gislayer",
    "gisfilter",
    "gisradius"
})
public class GISLAYERCRITERIA_Type {

    @XmlElement(name = "GISLAYER", required = true)
    protected String gislayer;
    @XmlElement(name = "GISFILTER")
    protected Long gisfilter;
    @XmlElement(name = "GISRADIUS")
    protected GISLAYERCRITERIA_Type.GISRADIUS gisradius;

    /**
     * Gets the value of the gislayer property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGISLAYER() {
        return gislayer;
    }

    /**
     * Sets the value of the gislayer property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGISLAYER(String value) {
        this.gislayer = value;
    }

    /**
     * Gets the value of the gisfilter property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGISFILTER() {
        return gisfilter;
    }

    /**
     * Sets the value of the gisfilter property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGISFILTER(Long value) {
        this.gisfilter = value;
    }

    /**
     * Gets the value of the gisradius property.
     * 
     * @return
     *     possible object is
     *     {@link GISLAYERCRITERIA_Type.GISRADIUS }
     *     
     */
    public GISLAYERCRITERIA_Type.GISRADIUS getGISRADIUS() {
        return gisradius;
    }

    /**
     * Sets the value of the gisradius property.
     * 
     * @param value
     *     allowed object is
     *     {@link GISLAYERCRITERIA_Type.GISRADIUS }
     *     
     */
    public void setGISRADIUS(GISLAYERCRITERIA_Type.GISRADIUS value) {
        this.gisradius = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="DISTANCE" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
     *         &lt;element name="UOM" type="{http://schemas.datastream.net/MP_fields}TYPE_Type"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "distance",
        "uom"
    })
    public static class GISRADIUS {

        @XmlElement(name = "DISTANCE", required = true)
        protected QUANTITY distance;
        @XmlElement(name = "UOM", required = true)
        protected TYPE_Type uom;

        /**
         * Gets the value of the distance property.
         * 
         * @return
         *     possible object is
         *     {@link QUANTITY }
         *     
         */
        public QUANTITY getDISTANCE() {
            return distance;
        }

        /**
         * Sets the value of the distance property.
         * 
         * @param value
         *     allowed object is
         *     {@link QUANTITY }
         *     
         */
        public void setDISTANCE(QUANTITY value) {
            this.distance = value;
        }

        /**
         * Gets the value of the uom property.
         * 
         * @return
         *     possible object is
         *     {@link TYPE_Type }
         *     
         */
        public TYPE_Type getUOM() {
            return uom;
        }

        /**
         * Sets the value of the uom property.
         * 
         * @param value
         *     allowed object is
         *     {@link TYPE_Type }
         *     
         */
        public void setUOM(TYPE_Type value) {
            this.uom = value;
        }

    }

}

==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/GISLAYERCRITERIA_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour GISLAYERCRITERIA_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GISLAYERCRITERIA_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GISLAYER"/>
 *         &lt;element name="GISFILTER" type="{http://www.w3.org/2001/XMLSchema}long" minOccurs="0"/>
 *         &lt;element name="GISRADIUS" minOccurs="0">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element name="DISTANCE" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *                   &lt;element name="UOM" type="{http://schemas.datastream.net/MP_fields}TYPE_Type"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GISLAYERCRITERIA_Type", propOrder = {
    "gislayer",
    "gisfilter",
    "gisradius"
})
public class GISLAYERCRITERIA_Type {

    @XmlElement(name = "GISLAYER", required = true)
    protected String gislayer;
    @XmlElement(name = "GISFILTER")
    protected Long gisfilter;
    @XmlElement(name = "GISRADIUS")
    protected GISLAYERCRITERIA_Type.GISRADIUS gisradius;

    /**
     * Obtient la valeur de la propriété gislayer.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGISLAYER() {
        return gislayer;
    }

    /**
     * Définit la valeur de la propriété gislayer.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGISLAYER(String value) {
        this.gislayer = value;
    }

    /**
     * Obtient la valeur de la propriété gisfilter.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGISFILTER() {
        return gisfilter;
    }

    /**
     * Définit la valeur de la propriété gisfilter.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGISFILTER(Long value) {
        this.gisfilter = value;
    }

    /**
     * Obtient la valeur de la propriété gisradius.
     * 
     * @return
     *     possible object is
     *     {@link GISLAYERCRITERIA_Type.GISRADIUS }
     *     
     */
    public GISLAYERCRITERIA_Type.GISRADIUS getGISRADIUS() {
        return gisradius;
    }

    /**
     * Définit la valeur de la propriété gisradius.
     * 
     * @param value
     *     allowed object is
     *     {@link GISLAYERCRITERIA_Type.GISRADIUS }
     *     
     */
    public void setGISRADIUS(GISLAYERCRITERIA_Type.GISRADIUS value) {
        this.gisradius = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element name="DISTANCE" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
     *         &lt;element name="UOM" type="{http://schemas.datastream.net/MP_fields}TYPE_Type"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "distance",
        "uom"
    })
    public static class GISRADIUS {

        @XmlElement(name = "DISTANCE", required = true)
        protected QUANTITY distance;
        @XmlElement(name = "UOM", required = true)
        protected TYPE_Type uom;

        /**
         * Obtient la valeur de la propriété distance.
         * 
         * @return
         *     possible object is
         *     {@link QUANTITY }
         *     
         */
        public QUANTITY getDISTANCE() {
            return distance;
        }

        /**
         * Définit la valeur de la propriété distance.
         * 
         * @param value
         *     allowed object is
         *     {@link QUANTITY }
         *     
         */
        public void setDISTANCE(QUANTITY value) {
            this.distance = value;
        }

        /**
         * Obtient la valeur de la propriété uom.
         * 
         * @return
         *     possible object is
         *     {@link TYPE_Type }
         *     
         */
        public TYPE_Type getUOM() {
            return uom;
        }

        /**
         * Définit la valeur de la propriété uom.
         * 
         * @param value
         *     allowed object is
         *     {@link TYPE_Type }
         *     
         */
        public void setUOM(TYPE_Type value) {
            this.uom = value;
        }

    }

}
